@@ -29,7 +29,7 @@ class Orgs(DataModel, DB.Base):
 
     domains = relationship("Domains", back_populates="org")
 
-    _dictmapping_ = ((Id(), Text("name", flags="patch")), (Text("description", flags="patch"),),
+    _dictmapping_ = ((Id(), Text("name", flags="patch")), (Text("description", flags="patch"), Int("domainCount")),
                      (RefProp("domains", flags="patch"),))
 
     def fromdict(self, patches, *args, **kwargs):
@@ -418,21 +418,25 @@ from . import misc
 
 if sqlalchemy.__version__.split(".") >= ["1", "4"]:
     inspect(Domains).add_property("activeUsers",
-                                  column_property(select([func.count(Users.ID)])
+                                  column_property(select(func.count(Users.ID))
                                                   .where(Users.domainID == Domains.ID, Users.addressStatus == Users.NORMAL,
                                                          Users.maildir != "")
                                                   .scalar_subquery()))
     inspect(Domains).add_property("inactiveUsers",
-                                  column_property(select([func.count(Users.ID)])
+                                  column_property(select(func.count(Users.ID))
                                                   .where(Users.domainID == Domains.ID,
                                                          Users.addressStatus.not_in((Users.NORMAL, Users.SHARED)),
                                                          Users.maildir != "")
                                                   .scalar_subquery()))
     inspect(Domains).add_property("virtualUsers",
-                                  column_property(select([func.count(Users.ID)])
+                                  column_property(select(func.count(Users.ID))
                                                   .where(Users.domainID == Domains.ID, (Users.addressStatus == Users.SHARED) |
                                                          (Users.maildir == ""))
                                                   .scalar_subquery()))
+    inspect(Orgs).add_property("domainCount",
+                               column_property(select(func.count(Domains.ID))
+                                               .where(Domains.orgID == Orgs.ID)
+                                               .scalar_subquery()))
 else:
     inspect(Domains).add_property("activeUsers",
                                   column_property(select([func.count(Users.ID)])
@@ -450,5 +454,9 @@ else:
                                                   .where((Users.domainID == Domains.ID) &
                                                          ((Users.addressStatus == Users.SHARED) | (Users.maildir == "")))
                                                   .as_scalar()))
+    inspect(Orgs).add_property("domainCount",
+                               column_property(select([func.count(Domains.ID)])
+                                               .where(Domains.orgID == Orgs.ID)
+                                               .as_scalar()))
 
 Domains.NTregister()
