@@ -68,6 +68,8 @@ class Users(DataModel, DB.Base, NotifyTable):
             tag = PropTags.deriveTag(k)
             name = self._name(k)
             if not PropTypes.ismv(tag):
+                if isinstance(v, (bytes, str)) and len(v) > 4000:
+                    return  # Value is to long to be stored, omit to avoid corrupting store properties
                 if tag in self.__struct:
                     if v is None:
                         DB.session.delete(self.__struct[tag])
@@ -164,7 +166,7 @@ class Users(DataModel, DB.Base, NotifyTable):
     _dictmapping_ = ((Id(), Text("username", flags="patch")),
                      (Id("domainID", flags="init"),
                       {"attr": "ldapID", "flags": "patch"},
-                      Int("status", flags="patch")),
+                      Int("status", filter="set", flags="patch")),
                      (Text("lang", match=False, flags="patch"),
                       BoolP("pop3_imap", flags="patch"),
                       BoolP("smtp", flags="patch"),
@@ -265,11 +267,15 @@ class Users(DataModel, DB.Base, NotifyTable):
         if props is None:
             return
         status = props.pop("domainStatus") << 4
+        # Cache domainnames in the same organization to enforce valid aliases
+        # Necessary because retrieving domainnames causes the partially created user to be flushed, resulting in DB errors
+        self.orgDomains = {d._domainname for d in Domains.query.filter(Domains.orgID == props["domain"].orgID)
+                                                               .with_entities(Domains._domainname)}
         self.fromdict(props, *args, **kwargs)
         self.addressStatus = (self.addressStatus or 0) | status
 
     def fromdict(self, patches, syncStore=True, *args, **kwargs):
-        isContact = patches.get("status", self.status) != Users.CONTACT
+        isContact = patches.get("status", self.status) == Users.CONTACT
         if "username" in patches and patches["username"] != self.username:
             from orm.domains import Domains
             username = patches.pop("username")
@@ -580,6 +586,14 @@ class Users(DataModel, DB.Base, NotifyTable):
             logger.warning("Failed to update chat user")
         self._chatUser["roles"] = tmpRoles
 
+    @validates("aliases")
+    def checkAlias(self, key, value, *args):
+        domains = getattr(self, "orgDomains", None) or\
+                  [d._domainname for d in Domains.query.with_entities(Domains._domainname).filter(Domains.orgID == self.orgID)]
+        if not value.aliasname.split('@')[1] in domains:
+            raise ValueError(f"Cannot use alias from foreign domain: {value.aliasname}")
+        return value
+
     @validates("_syncPolicy")
     def triggerSyncPolicyUpdate(self, key, value, *args):
         if value != self._syncPolicy:
@@ -844,6 +858,7 @@ class Aliases(DataModel, DB.Base, NotifyTable):
     def __init__(self, aliasname, main, *args, **kwargs):
         if main.ID == 0:
             raise ValueError("Cannot alias superuser")
+        self.aliasname = aliasname
         self.main = main
         self.fromdict(aliasname)
 
